==> nextcloud-18.0.3.tgz: nextcloud/apps/accessibility/l10n/sv.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Mörkt tema",
    "Enable dark theme" : "Aktivera mörkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ett mörkt tema för att lätta dina ögon genom att minska den allmänna ljusstyrkan. Det är fortfarande under utveckling, så rapportera gärna eventuella problem ni hittar.",
    "High contrast mode" : "Läge med hög kontrast",
    "Enable high contrast mode" : "Aktivera läge med hög kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ett läge med hög kontrast för att underlätta din navigering. Visuell kvalitet kommer att minska men tydligheten ökar.",
    "Dyslexia font" : "Dyslexi-typsnitt",
    "Enable dyslexia font" : "Aktivera dyslexi-typsnitt",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic är ett fritt typsnitt/font som är utformat för att mildra några av de vanligaste lässvårigheterna som orsakas av dyslexi.",
    "Accessibility" : "Tillgänglighet",
    "Accessibility options for nextcloud" : "Tillgänglighetsalternativ för Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Ger flera tillgänglighetsalternativ för att underlätta din användning av Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Allmän åtkomst är mycket viktig för oss. Vi följer webbstandarder och kontrollerar att allt är användbart även utan mus och hjälpmedel som skärmläsare. Vi strävar efter att följa {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 på AA-nivå, med temat hög kontrast även på AAA-nivå.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Om du hittar några problem, tveka inte att rapportera dem på {issuetracker}vår issue tracker{linkend}. Och om du vill engagera dig, gå med i {designteam}vårt design team{linkend}!",
    "High contrast theme" : "Högkontrasttema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ett tema med hög kontrast för att underlätta din navigering. Visuell kvalitet kommer att minskas men klarhet kommer att ökas.",
    "Dark theme (beta)" : "Mörkt tema (beta)",
    "Web Content Accessibility Guidelines" : "Riktlinjer för webbinnehåll ur tillgänglighetssynpunkt",
    "our issue tracker" : "vår felrapportering",
    "our design team" : "vårt designteam",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "Allmän åtkomst är mycket viktig för oss. Vi följer webbstandarder och kontrollerar att allt är användbart även utan mus och hjälpmedel som skärmläsare. Vi strävar efter att följa {guidelines} 2.1 på AA-nivå, med temat hög kontrast även på AAA-nivå.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "Om du hittar några problem, tveka inte att rapportera dem på {issuetracker}. Och om du vill engagera dig, gå med i {designteam}!",
    "Enable" : "Aktivera"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.12.tgz: nextcloud/apps/accessibility/l10n/sv.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Mörkt tema",
    "Enable dark theme" : "Aktivera mörkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ett mörkt tema för att lätta dina ögon genom att minska den allmänna ljusstyrkan. Det är fortfarande under utveckling, så rapportera gärna eventuella problem ni hittar.",
    "High contrast mode" : "Läge med hög kontrast",
    "Enable high contrast mode" : "Aktivera läge med hög kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ett läge med hög kontrast för att underlätta din navigering. Visuell kvalitet kommer att minska men tydligheten ökar.",
    "Dyslexia font" : "Dyslexi-teckensnitt",
    "Enable dyslexia font" : "Aktivera dyslexi-teckensnitt",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic är ett fritt teckensnitt/font som är utformat för att mildra några av de vanligaste lässvårigheterna som orsakas av dyslexi.",
    "Accessibility" : "Tillgänglighet",
    "Accessibility options for nextcloud" : "Tillgänglighetsalternativ för Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Ger flera tillgänglighetsalternativ för att underlätta din användning av Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Allmän åtkomst är mycket viktig för oss. Vi följer webbstandarder och kontrollerar att allt är användbart även utan mus och hjälpmedel som skärmläsare. Vi strävar efter att följa {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 på AA-nivå, med temat hög kontrast även på AAA-nivå.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Om du hittar några problem, tveka inte att rapportera dem på {issuetracker}vår problemhanterare{linkend}. Och om du vill engagera dig, gå med i {designteam}vårt designteam{linkend}!"
},
"nplurals=2; plural=(n != 1);");
